[llvm-commits] CVS: llvm/include/llvm/Type.h

Misha Brukman brukman at cs.uiuc.edu
Tue May 20 13:47:00 PDT 2003


Changes in directory llvm/include/llvm:

Type.h updated: 1.23 -> 1.24

---
Log message:

s/convertable/convertible/g


---
Diffs of the changes:

Index: llvm/include/llvm/Type.h
diff -u llvm/include/llvm/Type.h:1.23 llvm/include/llvm/Type.h:1.24
--- llvm/include/llvm/Type.h:1.23	Mon Sep  2 20:04:11 2002
+++ llvm/include/llvm/Type.h	Tue May 20 13:45:20 2003
@@ -157,10 +157,10 @@
   ///
   inline bool isRecursive() const { return Recursive; }
 
   /// isLosslesslyConvertableTo - Return true if this type can be converted to
   /// 'Ty' without any reinterpretation of bits.  For example, uint to int.
   ///
-  bool isLosslesslyConvertableTo(const Type *Ty) const;
+  bool isLosslesslyConvertibleTo(const Type *Ty) const;
 
 
   /// Here are some useful little methods to query what type derived types are
@@ -157,10 +157,10 @@
   inline bool isRecursive() const { return Recursive; }
 
-  /// isLosslesslyConvertableTo - Return true if this type can be converted to
+  /// isLosslesslyConvertibleTo - Return true if this type can be converted to
   /// 'Ty' without any reinterpretation of bits.  For example, uint to int.
   ///





More information about the llvm-commits mailing list